aboutsummaryrefslogtreecommitdiff
path: root/room.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'room.cpp')
-rw-r--r--room.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/room.cpp b/room.cpp
index bc7c083e..d5079711 100644
--- a/room.cpp
+++ b/room.cpp
@@ -790,8 +790,8 @@ QString Room::roomMembername(const User* u) const
// << "is not a member of the room" << id();
// }
- // In case of more than one namesake, disambiguate with user id.
- return username % " (" % u->id() % ")";
+ // In case of more than one namesake, use the full name to disambiguate
+ return u->fullName();
}
QString Room::roomMembername(const QString& userId) const